pub struct ModuleGraph<N = Node> { /* private fields */ }Expand description
Details the FuncDefns, FuncDecls and module-level Consts in a Hugr,
in a Hugr, along with the Calls, LoadFunctions, and LoadConstants connecting them.
Each node in the ModuleGraph corresponds to a module-level function or const;
each edge corresponds to a use of the target contained in the edge’s source.
For Hugrs whose entrypoint is neither a Module nor a FuncDefn,
the static graph will have an additional StaticNode::NonFuncEntrypoint
corresponding to the Hugr’s entrypoint, with no incoming edges.
Implementations
Sourceimpl<N: HugrNode> ModuleGraph<N>
impl<N: HugrNode> ModuleGraph<N>
Sourcepub fn graph(&self) -> &Graph<StaticNode<N>, StaticEdge<N>>
pub fn graph(&self) -> &Graph<StaticNode<N>, StaticEdge<N>>
Allows access to the petgraph
Sourcepub fn node_index(&self, n: N) -> Option<NodeIndex<u32>>
pub fn node_index(&self, n: N) -> Option<NodeIndex<u32>>
Convert a Hugr Node into a petgraph node index.
Result will be None if n is not a FuncDefn,
FuncDecl or the HugrView::entrypoint.
Sourcepub fn out_edges(
&self,
n: N,
) -> impl Iterator<Item = (&StaticEdge<N>, &StaticNode<N>)>
pub fn out_edges( &self, n: N, ) -> impl Iterator<Item = (&StaticEdge<N>, &StaticNode<N>)>
Returns an iterator over the out-edges from the given Node, i.e. edges to the functions/constants called/loaded by it.
If the node is not recognised as a function or the entrypoint,
for example if it is a Const, the iterator will be empty.
Sourcepub fn in_edges(
&self,
n: N,
) -> impl Iterator<Item = (&StaticNode<N>, &StaticEdge<N>)>
pub fn in_edges( &self, n: N, ) -> impl Iterator<Item = (&StaticNode<N>, &StaticEdge<N>)>
Returns an iterator over the in-edges to the given Node, i.e. edges from the (necessarily) functions that call/load it.
If the node is not recognised as a function or constant, for example if it is a non-function entrypoint, the iterator will be empty.